/*
 * individual_types.h
 *
 *  Created on: 12 May 2020
 *      Author: gc1610
 */

#ifndef INDIVIDUAL_TYPES_H_
#define INDIVIDUAL_TYPES_H_

#include <Rcpp.h>
#include "CategoricalVariable.h"
#include "IntegerVariable.h"
#include "DoubleVariable.h"
#include "RaggedInteger.h"
#include "RaggedDouble.h"
#include "Event.h"

#endif /* INDIVIDUAL_TYPES_H_ */
